Crate ledgerstore

Crate ledgerstore 

Modules

ledger_cache

Structs

ItemRefCache
ItemReference
The way one item references another item
Ledger
LedgerEntry
OverrideLedger
Before inserting an item into the state, we want to check if all invariants are still upheld. This struct therefore contain the new item we want to validate. This allows us to pass in this in validation functions so when we check the new/modified items dependencies it’ll use the current state for other items, but when it checks invariants based on the new item it’ll load the new/modified item from memory
PropertyCache
TheLedgerEvent

Enums

EventError
LedgerType
TheCacheGetter
Represents a way to fetch an item based on either its properites
TheLedgerAction

Traits

LedgerItem
Represents how a ledger mutates or creates an item.
TimeProvider

Functions

load_file_contents

Type Aliases

CacheHash
CacheKey
Hashed
LedgerHash
ProviderId
StateHash
UnixSeconds