Modules
Structs
- Item
RefCache - Item
Reference - The way one item references another item
- Ledger
- Ledger
Entry - Override
Ledger - Before inserting an item into the state, we want to check if all invariants are still upheld. This struct therefore contain the new item we want to validate. This allows us to pass in this in validation functions so when we check the new/modified items dependencies it’ll use the current state for other items, but when it checks invariants based on the new item it’ll load the new/modified item from memory
- Property
Cache - TheLedger
Event
Enums
- Event
Error - Ledger
Type - TheCache
Getter - Represents a way to fetch an item based on either its properites
- TheLedger
Action
Traits
- Ledger
Item - Represents how a ledger mutates or creates an item.
- Time
Provider